@@ -1,6 +1,6 @@
 /* connection_commands.c
  *
- * $Id: connection_commands.c,v 1.30 2000/09/14 23:35:56 nisse Exp $
+ * $Id: connection_commands.c,v 1.31 2000/10/06 23:52:45 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -49,24 +49,23 @@
 /* GABA:
    (class
      (name connection_close_handler)
-     (super close_callback)
+     (super lsh_callback)
      (vars
        (connection object ssh_connection)))
 */
 
 static void
-connection_die(struct close_callback *c, int reason)
+connection_die(struct lsh_callback *c)
 {
   CAST(connection_close_handler, closure, c);
   
-  verbose("Connection died, for reason %i.\n", reason);
-  if (reason != CLOSE_EOF)
-    werror("Connection died.\n");
-
+  verbose("Connection died.\n");
+  
   KILL_RESOURCE_LIST(closure->connection->resources);
 }
 
-struct close_callback *make_connection_close_handler(struct ssh_connection *c)
+struct lsh_callback *
+make_connection_close_handler(struct ssh_connection *c)
 {
   NEW(connection_close_handler, closure);
 
