@@ -2,7 +2,7 @@
  *
  * An implementation of SPKI certificate checking
  *
- * $Id: spki.h,v 1.18 2000/09/19 18:42:22 nisse Exp $ */
+ * $Id: spki.h,v 1.19 2000/10/03 21:50:18 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -67,6 +67,17 @@ int spki_check_type(struct sexp *e, int type, struct sexp_iterator **res);
 struct sexp *
 make_ssh_hostkey_tag(struct address_info *host);
 
+struct verifier *
+spki_make_verifier(struct alist *algorithms,
+		   struct sexp *e);
+
+struct signer *
+spki_make_signer(struct alist *algorithms,
+		 struct sexp *e,
+		 int *type);
+
+struct sexp *
+spki_make_public_key(struct signer *signer);
 
 struct sexp *
 dsa_to_spki_public_key(struct dsa_public *p);
